==> qmmp_0.8.1.orig.tar.bz2: qmmp-0.8.1/src/plugins/General/udisks2/translations/udisks2_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>UDisks Plugin Settings</source>
        <translation>Einstellungen UDisks-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>Erkennung von Audio-CDs</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Titel automatisch zur Wiedergabeliste hinzufügen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Titel automatisch von der Wiedergabeliste entfernen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Erkennung von Wechseldatenträgern</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Dateien automatisch zur Wiedergabeliste hinzufügen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Dateien automatisch von der Wiedergabeliste entfernen</translation>
    </message>
</context>
<context>
    <name>UDisks2Factory</name>
    <message>
        <location filename="../udisks2factory.cpp" line="30"/>
        <source>UDisks2 Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="50"/>
        <source>About UDisks2 Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="51"/>
        <source>Qmmp UDisks2 Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="52"/>
        <source>This plugin provides removable devices detection using UDisks2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished">Autor: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>UDisks2Plugin</name>
    <message>
        <location filename="../udisks2plugin.cpp" line="130"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation type="unfinished">CD „%1“ hinzufügen</translation>
    </message>
    <message>
        <location filename="../udisks2plugin.cpp" line="138"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation type="unfinished">Gerät „%1“ hinzufügen</translation>
    </message>
</context>
</TS>

==> qmmp-0.12.18.tar.bz2: qmmp-0.12.18/src/plugins/General/udisks2/translations/udisks2_plugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>UDisks Plugin Settings</source>
        <translation>Einstellungen UDisks-Modul</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>CD Audio Detection</source>
        <translation>CD-Audio-Erkennung</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="38"/>
        <source>Add tracks to playlist automatically</source>
        <translation>Titel automatisch zur Wiedergabeliste hinzufügen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Remove tracks from playlist automatically</source>
        <translation>Titel automatisch von der Wiedergabeliste entfernen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Removable Device Detection</source>
        <translation>Wechsellaufwerkerkennung</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="64"/>
        <source>Add files to playlist automatically</source>
        <translation>Dateien automatisch zur Wiedergabeliste hinzufügen</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Remove files from playlist automatically</source>
        <translation>Dateien automatisch von der Wiedergabeliste entfernen</translation>
    </message>
</context>
<context>
    <name>UDisks2Factory</name>
    <message>
        <location filename="../udisks2factory.cpp" line="31"/>
        <source>UDisks2 Plugin</source>
        <translation>UDisks2-Modul</translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="51"/>
        <source>About UDisks2 Plugin</source>
        <translation>Über UDisks2-Modul</translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="52"/>
        <source>Qmmp UDisks2 Plugin</source>
        <translation>Qmmp UDisks2-Modul</translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="53"/>
        <source>This plugin provides removable devices detection using UDisks2</source>
        <translation>Dieses Modul bietet Wechsellaufwerkerkennung unter Verwendung von UDisks2</translation>
    </message>
    <message>
        <location filename="../udisks2factory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Geschrieben von: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>UDisks2Plugin</name>
    <message>
        <location filename="../udisks2plugin.cpp" line="129"/>
        <source>Add CD &quot;%1&quot;</source>
        <translation>CD „%1“ hinzufügen</translation>
    </message>
    <message>
        <location filename="../udisks2plugin.cpp" line="137"/>
        <source>Add Volume &quot;%1&quot;</source>
        <translation>Datenträger „%1“ hinzufügen</translation>
    </message>
</context>
</TS>
